/**************************************************************************************
This program pulls in firm identifier (Compustat code: gvkey), country of incorporation 
identifier (Compustat code: fic), fiscal year (Compustat code: fyear),and the year of
M&A law enactment. M&A law enacting countries and years of enactment are from Lel and
Miller (2015, RFS). Nonenacting countries are also from Lel and Miller (2015). The 
resulting datasets serve the basis for compiling the final dataset for the main analyses. 
****************************************************************************************/

libname a'C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International takeover and conservatism\data';
libname b'C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\wrds dataset\Compustat Global';


/* import international M&A laws list by country. The list includes both enacting countries 
and nonenacting countries. Nonenacting countries have missing information on the year of
law enactment */
proc import datafile='C:\Users\Wei-Wang-T470\Desktop\My Research\My SAS Files\International data\international takeover acts.xlsx'
	out=takeover dbms=xlsx replace;
run;

/* retrieve company identifier (gvkey), fiscal year (fyear), fiscal year end date (datadate), 
and country of incorporation identifier (fic) from Compustat Global Fundamentals Annual 
File */
data funda;
	set b.g_funda;
	keep gvkey fyear datadate fic;
	where indfmt='INDL' and consol='C';
run;

proc sort data=funda nodupkey; 
by gvkey fyear; 
run;

/* merge FUNDA dataset with M&A law country list to get the enactment year */
proc sql;
	create table funda1
	as select a.*, b.takeoverlaw_year as lawyear
	from funda as a, takeover as b
	where a.fic=b.countrycode;
quit;

/* retain countries that passed M&A laws from 1995 through 2002 */
data takeovercountry;
	set funda1;
	where 1995<=lawyear<=2002;
run;

/* check and verify the 12 M&A law enacting countries. The fic codes for those countries are
'AUT','CHL',DEU','IDN','IND','IRL','LKA','MYS','NZL','PAK','PHL','TWN'. */
proc sort data=takeovercountry nodupkey out=checktakeover;
	by fic;
run;

/* bring in SIC industry classification code from Compustat Global Names File */
data names;
	set b.g_names;
run;

proc sql;
	create table takeovercountry1
	as select a.*, b.sic
	from takeovercountry as a, names as b
	where a.gvkey=b.gvkey
	order by gvkey,fyear;
quit;

/* get two-digit SIC code */
data takeovercountry1a;
	set takeovercountry1;
	sic2 = int(sic/100);
run;

/* remove firms in financial services industries: two-digit SIC code 60 */
data takeovercountry2;
	set takeovercountry1a;
	where sic2 ne 60;
run;

/* save to local drive firm-years from enacting countries */
data a.takeovercountry;
	set takeovercountry2;
run;

/* nonenacting countries are those that did not pass M&A law */
data nontakeovercountry;
	set funda1;
	where lawyear=.;
run;

/* check and verify that there are 22 nonenacting countries. The fic codes for those
countries are 'ARG','BRA','CHN','COL','CZE','DNK','FRA','GRC','HUN','ISR','JPN',
'KOR','LUX','MEX','NOR','PER','POL','PRT','THA','TUR','VEN','ZWE'. */
proc sort data=nontakeovercountry nodupkey out=checknontakeover;
	by fic;
run;

/* get two-digist SIC code */
proc sql;
	create table nontakeovercountry1
	as select a.*, b.sic
	from nontakeovercountry as a, names as b
	where a.gvkey=b.gvkey
	order by gvkey,fyear;
quit;

data nontakeovercountry1a;
	set nontakeovercountry1;
	sic2 = int(sic/100);
run;

/* remove firms in financial services industries: two-digit SIC code 60 */
data nontakeovercountry2;
	set nontakeovercountry1a;
	where sic2 ne 60;
run;

/* save to local drive firm-years from nonenacting countries */
data a.nontakeovercountry;
	set nontakeovercountry2;
run;










